@@ -6,10 +6,16 @@
 # Copyright © 2007–14 martin f. krafft <madduck@madduck.net>
 # Released under the terms of the Artistic Licence 2.0
 #
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 from reclass.storage.loader import StorageBackendLoader
 
 import unittest
 
+
 class TestLoader(unittest.TestCase):
 
     def test_load(self):
